"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.registerCommands = void 0;
const command_1 = require("./command/command");
const command_registration_1 = require("./command/command-registration");
const shortcut_converters_1 = require("./shortcut/shortcut-converters");
function addShortcutToMap(map, shortcut, commandOptions) {
    const nativeShortcut = typeof shortcut === "string"
        ? shortcut_converters_1.getNativeShortcutFromString(shortcut)
        : shortcut;
    if (map.get(nativeShortcut) !== undefined) {
        throw Error("You cannot register a command with a keyset that has previously been registered. Either deregister the existing command or choose a different keyset.");
    }
    let command;
    if (command_registration_1.isCommandFunction(commandOptions)) {
        command = { run: commandOptions };
    }
    else if (command_registration_1.isCommandOptions(commandOptions)) {
        command = commandOptions;
    }
    else {
        throw Error("Command options must either be a function or be an object containing the properties `run` and `when`.");
    }
    map.set(nativeShortcut, command);
}
class CommandPalette {
    constructor() {
        this.activeChord = undefined;
        this.commands = new Map();
        window.addEventListener("keydown", (event) => this.handleKeyDown(event));
    }
    static getInstance() {
        return CommandPalette.instance;
    }
    registerCommands(options) {
        Object.keys(options).forEach((optKey) => {
            let map = this.commands;
            if (optKey.search(" ") > -1) {
                const chordInitializer = shortcut_converters_1.getNativeShortcutFromString(optKey.split(" ")[0]);
                let shortcutMap = this.commands.get(chordInitializer);
                if (shortcutMap === undefined) {
                    shortcutMap = new Map();
                    this.commands.set(chordInitializer, shortcutMap);
                }
                else if (command_1.isCommand(shortcutMap)) {
                    throw Error("You cannot register a chord that starts with a keyset previously used for a command. Either deregister the existing command or choose a different keyset.");
                }
                map = shortcutMap;
            }
            addShortcutToMap(this.commands, optKey, options[optKey]);
        });
    }
    handleKeyDown(event) {
        const shortcut = shortcut_converters_1.getNativeShortcutFromEvent(event);
        if (this.activeChord !== undefined) {
            const command = this.activeChord.get(shortcut);
            if (command !== undefined &&
                (command.when === undefined || command.when())) {
                command.run(event);
            }
            else {
                this.activeChord = undefined;
            }
        }
        else {
            const command = this.commands.get(shortcut);
            if (command !== undefined) {
                event.preventDefault();
                if (command_1.isCommand(command) &&
                    (command.when === undefined || command.when())) {
                    command.run(event);
                }
                else if (command_1.isShortcutMap(command)) {
                    this.activeChord = command;
                }
            }
        }
    }
}
CommandPalette.instance = new CommandPalette();
function registerCommands(options) {
    CommandPalette.getInstance().registerCommands(options);
}
exports.registerCommands = registerCommands;
//# sourceMappingURL=index.js.map