"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getNativeShortcutFromEvent = exports.getNativeShortcutFromString = void 0;
const platform_1 = require("../util/platform");
function getNativeShortcutFromString(str) {
    if (str === "") {
        throw new Error("Shortcut string cannot be empty.");
    }
    const splitStr = str.split("+");
    const code = splitStr.find((s) => s !== "mod" && s !== "opt" && s !== "shift");
    if (code === undefined || code === null) {
        throw new Error("Your shortcut must include a key code corresponding to a valid 'KeyboardEvent.code' value.");
    }
    if (platform_1.getPlatform() === platform_1.Platform.Apple) {
        return {
            altKey: splitStr.some((s) => s === "opt"),
            code,
            metaKey: splitStr.some((s) => s === "mod"),
            shiftKey: splitStr.some((s) => s === "shift"),
        };
    }
    return {
        altKey: splitStr.some((s) => s === "opt"),
        code,
        ctrlKey: splitStr.some((s) => s === "mod"),
        shiftKey: splitStr.some((s) => s === "shift"),
    };
}
exports.getNativeShortcutFromString = getNativeShortcutFromString;
function getNativeShortcutFromEvent(event) {
    if (platform_1.getPlatform() === platform_1.Platform.Apple) {
        return {
            altKey: event.altKey,
            code: event.code,
            metaKey: event.metaKey,
            shiftKey: event.shiftKey,
        };
    }
    return {
        altKey: event.altKey,
        code: event.code,
        ctrlKey: event.ctrlKey,
        shiftKey: event.shiftKey,
    };
}
exports.getNativeShortcutFromEvent = getNativeShortcutFromEvent;
//# sourceMappingURL=shortcut-converters.js.map